"""
As an extension of the witness set for the twisted cubic,
we consider the decomposition of the twisted cubic and line.
The decomposition is computed via monodromy on the witness
set for the one dimensional solution set.
"""
# f = ['(x^2 - y)*(y-0.5);', '(x^3 - z)*(z-0.5);']
f = ['x^2 - y;', 'x^3 - z;']
print 'polynomials that define an algebraic set:'
for pol in f:
    print pol
from phcpy.sets import embed, cascade_step
from phcpy.solver import solve
ef = embed(3, 1, f)
# patch : make sure zz1 is last symbol!
ef[0] = 'x - x + y - y + z - z + ' + ef[0]
efsols = solve(ef)
print 'degree of the set :', len(efsols)
from phcpy.sets import monodromy_breakup
monodromy_breakup(ef, efsols, 1)



def PHC_File_Status(file_id):
   from os import path, system, remove
   status = 0
   if path.isfile(file_id+'.sta'):
      f = open(file_id+'.sta','r')
      if f.readline() == 'submitted':
         status = 1
         if path.isfile(file_id+".sol") and  path.isfile(file_id+".poly"):
            sol_file_size  = path.getsize(file_id+".sol")
            poly_file_size = path.getsize(file_id+".poly")
            if sol_file_size > 3 and sol_file_size != poly_file_size: 
                status = 2
      f.close()
   return status
            
def PHC_Status(Uid, poly_id, file_id, phcdb):
   status = phcdb.check_poly_status(Uid, poly_id)
   if status == 1:
      return PHC_File_Status(file_id)
   else:
      return status
